@@ -365,9 +365,7 @@ def getRunProc():
 
     if not os.access('/proc', os.R_OK):
         return []
-    return map(getCmd,
-               list(filter(lambda x: x.isdigit(),
-                      listDirectory('/proc'))))
+    return [getCmd(x) for x in listDirectory('/proc') if x.isdigit()]
 
 
 def owner(pid):
