@@ -324,9 +324,8 @@ class MessageDispatcher(object):
 
     def ask_choice(self, message):
         message, answers = message.message.split('|')
-        answers = map(lambda x: (x[0], x[1].strip(')')),
-                      map(lambda x: x.split('('),
-                          answers.split(',')))
+        answers = [(x[0], x[1].strip(')')) for x 
+                in (y.split('(') for y in answers.split(','))]
         answer = self.methods.askChoice(message, answers)
         self.parent.send_message(answer)
 
