@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 # Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
@@ -14,16 +14,16 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+from importlib import reload
 
 def console_main():
     import sys
-    from calculate.console.application.cl_client import main, StoppableThread
-    from calculate.console.application.function import _print
+    from .application.cl_client import main, StoppableThread
+    from .application.function import _print
 
     reload(sys)
-    sys.setdefaultencoding("utf-8")
-    import __builtin__
-
+    # sys.setdefaultencoding("utf-8")
+    import builtins as __builtin__
     from calculate.lib.cl_lang import setLocalTranslate
 
     _ = lambda x: x
@@ -36,5 +36,5 @@ def console_main():
     except KeyboardInterrupt:
         wait_thread.stop()
         red = '\033[31m * \033[0m'
-        print '\n' + red + _('Manually interrupted')
+        print('\n' + red + _('Manually interrupted'))
         sys.exit(1)
